
Recurrence network analysis of the logistic map
===============================================

This tutorial demonstrates how to use ``timeseries`` for a nonlinear time
series analysis of a realization of the chaotic logistic map.

This tutorial is also available as an ipython notebook.

.. literalinclude:: ../../../examples/tutorials/recurrence_network.py
